# vsng-colab


## Installation

```bash
pip install vsng-colab
```

## Example

```python
from  vsngcolabi import configure
configure()
# configure(mount = True , folder = "/content/drive/MyDrive/home" )
```

Steps  : 
*   create secret in colab secrets called NGROK_TOKEN and set its value .


